slepc-3.18.0 2022-10-01
Report Typos and Errors

# NEPSetTwoSided

Sets the solver to use a two-sided variant so that left eigenvectors are also computed.

### Synopsis

    #include "slepcnep.h"
    PetscErrorCode NEPSetTwoSided(NEP nep,PetscBool twosided)

Logically Collective on nep

### Input Parameters

| nep | - the eigensolver context
| twosided | - whether the two-sided variant is to be used or not

### Options Database Keys

| -nep_two_sided <boolean> | - Sets/resets the twosided flag

### Notes

If the user sets twosided=PETSC_TRUE then the solver uses a variant of the algorithm that computes both right and left eigenvectors. This is usually much more costly. This option is not available in all solvers.

When using two-sided solvers, the problem matrices must have both the MatMult and MatMultTranspose operations defined.

### See Also

NEPGetTwoSided(), NEPGetLeftEigenvector()

### Level

advanced

### Location

src/nep/interface/nepopts.c

### Examples

src/nep/tutorials/ex42.c.html
Index of all NEP routines
Table of Contents for all manual pages
Index of all manual pages